@@ -23,6 +23,8 @@ import re
 #import gc
 #import multiprocessing
 
+from __init__ import __version__
+
 def get_options():
     parser = argparse.ArgumentParser(#            description=__doc__,
             formatter_class=argparse.ArgumentDefaultsHelpFormatter,
@@ -81,14 +83,20 @@ def get_options():
 #            help='use multiple processors for generating the report',
 #            default=False)
 #    parser.add_option_group(notimplemented_group)
+
     parser.add_argument('-u', '--no-debug', dest='debug', action='store_false', 
             help="disable debugging messages, which are enabled by default", default=False)
+    parser.add_argument('--version', dest='show_version', action='store_true', 
+            help="Show current version and exit", default=False)
     options = parser.parse_args()
     
+    if options.show_version is True:
+        print __version__
+        os.sys.exit(0)
 #    if options.parallelize is True:
 #        raise NotImplementedError("parallelization wasn't working correctly, so I removed the code for it.")
-    if options.report_type in ("interpop_comparison", ):
-        raise NotImplementedError("interpop comparison report not implemented yet")
+#    if options.report_type in ("interpop_comparison", ):
+#        raise NotImplementedError("Sorry, interpop comparison report not implemented yet")
     if options.debug is True:
 #        logging.basicConfig(level=logging.DEBUG, filename='logs/network_report.log')
         logging.basicConfig(level=logging.DEBUG)
@@ -98,9 +106,28 @@ def get_options():
     else:
         try:
             if os.stat(options.vcf_file).st_size == 0:
-                parser.error("\n\n\t\tThe VCF file provided ({0}) seems to be empty.\n\nPlease use vcf2networks --help to get usage information\n\nCheck also our tutorial at https://bitbucket.org/dalloliogm/vcf2networks for some examples.".format(options.vcf_file))
+                parser.error("\n\n\t\tThe VCF file provided ({0}) seems to be empty.\n\nPlease use vcf2networks --help to get usage information\n\nCheck also our tutorial at https://bitbucket.org/dalloliogm/vcf2networks for some examples.\n".format(options.vcf_file))
         except:
-            parser.error("\n\n\t\tI can not parse the VCF file provided ({0}).\n\nPlease use vcf2networks --help to get usage information\n\nCheck also our tutorial at https://bitbucket.org/dalloliogm/vcf2networks for some examples.".format(options.vcf_file))
+            parser.error("\n\n\t\tI can not parse the VCF file provided ({0}).\n\nPlease use vcf2networks --help to get usage information\n\nCheck also our tutorial at https://bitbucket.org/dalloliogm/vcf2networks for some examples.\n".format(options.vcf_file))
+
+    if options.params_file is False:
+        logging.warning("no configuration file provided, so using default values. Please specify one with the --config option, to customize which network properties must be included in the output report. Check our tutorial at https://bitbucket.org/dalloliogm/vcf2networks for some examples.\n")
+        options.params = {
+                'networkproperties_report_fields': ['file_prefix', 'n_snps', 'chromosome', 'n_datapoints', 'n_components', 'av_degree', 'av_path_length'],
+                'allvalues_report_fields': ['network_gene', 'network_continent', 'network_distance_definition', 'cont_str', 'n_datapoints', 'degree'],
+#                'individuals_file': 'data/individuals/individuals_annotations.txt'
+                }
+    else:
+        options.params = yaml.load(open(options.params_file, 'r'))
+
+    if options.individuals_file == "":
+        if options.params.has_key('individuals_annotations'):
+            options.individuals_file = options.params['individuals_annotations']
+        else:
+            parser.error("no individuals file (--individuals_file option) provided")
+    if not os.path.isfile(options.individuals_file): 
+        parser.error('\n\n\t\tInvalid individuals file. Please specify one with the --individuals option, or inside the parameters file.\n\nPlease use vcf2networks --help to get usage information.\n\nCheck also our tutorial at https://bitbucket.org/dalloliogm/vcf2networks for some examples.\n')
+#    try: with open(options.vcf_file) as f: pass except IOError as e: 'Invalid VCF file file. Please specify one with the -i option, or in the parameters file'
 
     return (options)
 
@@ -207,22 +234,6 @@ def main():
 #    if options.windows_size != 0:
 #    (genotypes_lines, unphased_genotypes, snp_ids, snp_annotations ) = filteredvcf_to_binary.read_genotypes_vcf(options.vcf_file)
 
-    # Get the name of the individuals_file
-    if options.params_file is False:
-        options.params = {
-                'networkproperties_report_fields': ['file_prefix', 'n_snps', 'chromosome', 'n_datapoints', 'n_components', 'av_degree', 'av_path_length'],
-                'individuals_file': 'data/individuals/individuals_annotations.txt'}
-    else:
-        options.params = yaml.load(open(options.params_file, 'r'))
-
-#    print options.params_file
-    if options.individuals_file == "":
-        if options.params.has_key('individuals_annotations'):
-            options.individuals_file = options.params['individuals_annotations']
-        else:
-            argparse.error("no individuals file (--individuals_file option) provided")
-    if not os.path.isfile(options.individuals_file): argparse.error('Invalid individuals file. Please specify one with the -i option, or in the parameters file')
-#    try: with open(options.vcf_file) as f: pass except IOError as e: 'Invalid VCF file file. Please specify one with the -i option, or in the parameters file'
 
     # Generate a temporary file containing the genotypes.
     options.use_hdf5 = False
